	pro tomsetup,star,g,fratio,sbcm1,sbcm2,ismfile,wave,obsspec,recspec,pshift,ratio,simspec

        ; Tomography parameter set up for spectra reconstruction. 
	; Run from subdirectory containing the spectrum stack

	; Input:
	;       star    = name of the spectrum stack
	;       g       = indices of good spectra (non-eclipse phase)
	;       fratio  = flux(secondary) / flux(primary) 
	;       sbcm1   = sbcm.out file for primary
	;       sbcm2   = sbcm.out file for secondary
	;       ismfile = name of ISM line spectrum file

        ; Output:
	;       wave    = wavelength vector for stack
        ;       obsspec = observed composite spectra
        ;       recspec = reconstructed spectra (current estimate) 
        ;       pshift  = pixel shifts for each spectrum, component
        ;       ratios  = flux ratio for each spectrum, component

	; get input spectra
	readstk,wave,obsspec,hjd,star

	; select non-eclipse phase spectra
	; g=[13,14,15,16,19,20,21,22,23,24,25,26,27,28,29,30,31,34,35,36]
	obsspec=obsspec(*,g)
	hjd=hjd(g)

	; number of reconstructed components
	n=2  ; simple binary, no tertiary
	npix=n_elements(wave)
	recspec=fltarr(npix,n)+1.  ; assume continuum to start
	nsp=n_elements(hjd)
	pshift=fltarr(n,nsp)
	ratio=fltarr(n,nsp)
	ratio(0,*)=1./(1.+fratio)
	ratio(1,*)=fratio/(1.+fratio)

	; set pshift from calculated orbits
	readsbcm,sbcm1,d1,c
	readsbcm,sbcm2,d2,c
	d1=d1(*,g)
	d2=d2(*,g)
	dv=deriv(wave)/wave*2.997925e5
	dvel=mean(dv)
	for i=0,nsp-1 do pshift(0,i)=d1(2,i)/dvel
	for i=0,nsp-1 do pshift(1,i)=d2(2,i)/dvel

	; read in ism spectrum and remove from data
	ism=readfits(ismfile)
	for i=0,nsp-1 do obsspec(0,i)=obsspec(*,i)/ism

	; advice
	print,' Running the tomography algorithm ... '
	print,' TOMOGRAPHY,100,0.9,obsspec,recspec,pshift,ratio,simspec'
	TOMOGRAPHY,100,0.9,obsspec,recspec,pshift,ratio,simspec
	plot,wave,recspec(*,0)
	oplot,wave,recspec(*,1)-0.5

	return
	end

@readstk.pro
@readsbcm.pro
@tomography.pro
